@@ -1,4 +1,4 @@
-// Copyright (C) 2010-2023 Joel Rosdahl and other contributors
+// Copyright (C) 2010-2024 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -16,11 +16,10 @@
 // this program; if not, write to the Free Software Foundation, Inc., 51
 // Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-#include "../src/Hash.hpp"
+#include <ccache/Hash.hpp>
+#include <ccache/util/string.hpp>
 
-#include <util/string.hpp>
-
-#include "third_party/doctest.h"
+#include <doctest/doctest.h>
 
 TEST_SUITE_BEGIN("Hash");
 
