@@ -1,4 +1,4 @@
-// Copyright (C) 2021-2023 Joel Rosdahl and other contributors
+// Copyright (C) 2021-2024 Joel Rosdahl and other contributors
 //
 // See doc/AUTHORS.adoc for a complete list of contributors.
 //
@@ -16,9 +16,9 @@
 // this program; if not, write to the Free Software Foundation, Inc., 51
 // Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-#include <util/string.hpp>
+#include <ccache/util/string.hpp>
 
-#include <third_party/doctest.h>
+#include <doctest/doctest.h>
 
 #include <ostream> // https://github.com/doctest/doctest/issues/618
 #include <vector>
@@ -567,6 +567,24 @@ TEST_CASE("util::split_once")
   }
 }
 
+TEST_CASE("util::split_option_with_concat_path")
+{
+  using std::make_pair;
+  using std::nullopt;
+  const auto split = util::split_option_with_concat_path;
+
+  CHECK(split("-I/c/foo") == make_pair("-I", "/c/foo"));
+  CHECK(split("-W,path/c/foo") == make_pair("-W,path", "/c/foo"));
+  CHECK(split("-DMACRO") == make_pair("-DMACRO", nullopt));
+#ifdef _WIN32
+  CHECK(split("-I/C:/foo") == make_pair("-I", "/C:/foo"));
+  CHECK(split("-IC:/foo") == make_pair("-I", "C:/foo"));
+  CHECK(split("-W,path/c:/foo") == make_pair("-W,path", "/c:/foo"));
+  CHECK(split("-W,pathc:/foo") == make_pair("-W,path", "c:/foo"));
+  CHECK(split("-opt:value") == make_pair("-opt:value", nullopt));
+#endif
+}
+
 TEST_CASE("util::split_path_list")
 {
   CHECK(util::split_path_list("").empty());
